"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
var _typeof3 = require("@babel/runtime/helpers/typeof");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getOptionLabel = exports["default"] = exports.createValue = void 0;
var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));
var _typeof2 = _interopRequireDefault(require("@babel/runtime/helpers/typeof"));
var _react = _interopRequireWildcard(require("react"));
var _formFieldGrid = _interopRequireDefault(require("../form-field-grid/form-field-grid"));
var _validationError = require("../validation-error/validation-error");
var _select = _interopRequireDefault(require("@data-driven-forms/common/select"));
var _parseInternalValue = _interopRequireDefault(require("@data-driven-forms/common/select/parse-internal-value"));
var _useFieldApi2 = _interopRequireDefault(require("@data-driven-forms/react-form-renderer/use-field-api"));
var _TextField = _interopRequireDefault(require("@mui/material/TextField"));
var _CircularProgress = _interopRequireDefault(require("@mui/material/CircularProgress"));
var _ArrowDropDown = _interopRequireDefault(require("@mui/icons-material/ArrowDropDown"));
var _Autocomplete = _interopRequireDefault(require("@mui/material/Autocomplete"));
var _excluded = ["inputProps"],
  _excluded2 = ["value", "options", "label", "helperText", "validateOnMount", "meta", "isSearchable", "description", "classNamePrefix", "isMulti", "placeholder", "onInputChange", "isFetching", "noOptionsMessage", "hideSelectedOptions", "closeMenuOnSelect", "required", "onChange", "onFocus", "onBlur", "FormFieldGridProps", "TextFieldProps", "inputProps", "isClearable", "isDisabled", "loadingText"],
  _excluded3 = ["input", "isRequired", "isDisabled", "isReadOnly", "disabled", "multiple", "isMulti", "isClearable", "disableClearable", "loadingMessage", "loadingText", "noOptionsMessage", "noOptionsText", "closeMenuOnSelect"];
function _interopRequireWildcard(e, t) { if ("function" == typeof WeakMap) var r = new WeakMap(), n = new WeakMap(); return (_interopRequireWildcard = function _interopRequireWildcard(e, t) { if (!t && e && e.__esModule) return e; var o, i, f = { __proto__: null, "default": e }; if (null === e || "object" != _typeof3(e) && "function" != typeof e) return f; if (o = t ? n : r) { if (o.has(e)) return o.get(e); o.set(e, f); } for (var _t in e) "default" !== _t && {}.hasOwnProperty.call(e, _t) && ((i = (o = Object.defineProperty) && Object.getOwnPropertyDescriptor(e, _t)) && (i.get || i.set) ? o(f, _t, i) : f[_t] = e[_t]); return f; })(e, t); }
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { (0, _defineProperty2["default"])(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
/**
 * Returns label of selected option
 * @param {Object|Array} option currently selected option
 * @param {Array<Object>} options all options avaiable
 * @returns {String}
 */
var _getOptionLabel = exports.getOptionLabel = function getOptionLabel(option, options) {
  if (typeof option === 'undefined') {
    return '';
  }
  if (option === '') {
    return '';
  }
  if (Array.isArray(option) && option.length === 0) {
    return '';
  }
  if ((0, _typeof2["default"])(option) === 'object') {
    return option.label;
  }
  var item = options.find(function (_ref) {
    var value = _ref.value;
    return value === option;
  });
  return item && item.label || '';
};

/**
 * Function that creates correct DDF select value format
 * @param {Object|Array} option currently selected values
 * @param {Boolean} isMulti multiple select flag
 * @returns {Object|Array<Object>}
 */
var createValue = exports.createValue = function createValue(option, isMulti) {
  if (isMulti) {
    return Array.isArray(option) ? option.map(function (item) {
      return (0, _typeof2["default"])(item) === 'object' ? item : {
        value: item
      };
    }) : option;
  }
  return option;
};
var InternalSelect = function InternalSelect(_ref2) {
  var value = _ref2.value,
    options = _ref2.options,
    label = _ref2.label,
    helperText = _ref2.helperText,
    validateOnMount = _ref2.validateOnMount,
    meta = _ref2.meta,
    isSearchable = _ref2.isSearchable,
    description = _ref2.description,
    classNamePrefix = _ref2.classNamePrefix,
    isMulti = _ref2.isMulti,
    _ref2$placeholder = _ref2.placeholder,
    placeholder = _ref2$placeholder === void 0 ? 'Please choose' : _ref2$placeholder,
    _onInputChange = _ref2.onInputChange,
    isFetching = _ref2.isFetching,
    noOptionsMessage = _ref2.noOptionsMessage,
    hideSelectedOptions = _ref2.hideSelectedOptions,
    closeMenuOnSelect = _ref2.closeMenuOnSelect,
    required = _ref2.required,
    _onChange = _ref2.onChange,
    onFocus = _ref2.onFocus,
    onBlur = _ref2.onBlur,
    _ref2$FormFieldGridPr = _ref2.FormFieldGridProps,
    FormFieldGridProps = _ref2$FormFieldGridPr === void 0 ? {} : _ref2$FormFieldGridPr,
    _ref2$TextFieldProps = _ref2.TextFieldProps,
    _ref2$TextFieldProps2 = _ref2$TextFieldProps === void 0 ? {} : _ref2$TextFieldProps,
    textFieldInputProps = _ref2$TextFieldProps2.inputProps,
    TextFieldProps = (0, _objectWithoutProperties2["default"])(_ref2$TextFieldProps2, _excluded),
    _ref2$inputProps = _ref2.inputProps,
    inputProps = _ref2$inputProps === void 0 ? {} : _ref2$inputProps,
    isClearable = _ref2.isClearable,
    isDisabled = _ref2.isDisabled,
    _ref2$loadingText = _ref2.loadingText,
    loadingText = _ref2$loadingText === void 0 ? 'Loading...' : _ref2$loadingText,
    rest = (0, _objectWithoutProperties2["default"])(_ref2, _excluded2);
  var invalid = (0, _validationError.validationError)(meta, validateOnMount);
  // When isMulti is true, the "parseInternalValue" always creates new value array, we need to memoize it to not create new array instance
  // Memo is required to fix https://github.com/data-driven-forms/react-forms/issues/1366
  var internalValue = (0, _react.useMemo)(function () {
    return (0, _parseInternalValue["default"])(value, isMulti);
  }, [value, isMulti]);
  return /*#__PURE__*/_react["default"].createElement(_formFieldGrid["default"], FormFieldGridProps, /*#__PURE__*/_react["default"].createElement(_Autocomplete["default"], (0, _extends2["default"])({
    filterSelectedOptions: hideSelectedOptions,
    disabled: isDisabled,
    disableClearable: isClearable,
    popupIcon: isFetching ? /*#__PURE__*/_react["default"].createElement(_CircularProgress["default"], {
      size: 20,
      color: "inherit"
    }) : /*#__PURE__*/_react["default"].createElement(_ArrowDropDown["default"], null),
    fullWidth: true,
    loadingText: loadingText
  }, rest, {
    renderInput: function renderInput(params) {
      return /*#__PURE__*/_react["default"].createElement(_TextField["default"], (0, _extends2["default"])({
        onFocus: onFocus,
        onBlur: onBlur
      }, params, {
        required: required,
        error: !!invalid,
        helperText: invalid || (meta.touched || validateOnMount) && meta.warning || helperText || description,
        label: label,
        margin: "normal"
      }, TextFieldProps, {
        inputProps: _objectSpread(_objectSpread(_objectSpread(_objectSpread({}, params.inputProps), textFieldInputProps), inputProps), {}, {
          readOnly: !isSearchable,
          placeholder: !internalValue || internalValue.length === 0 ? placeholder : undefined
        })
      }));
    },
    noOptionsText: noOptionsMessage(),
    onInputChange: function onInputChange(_event, value) {
      return _onInputChange(value);
    },
    options: options,
    multiple: isMulti,
    getOptionLabel: function getOptionLabel(option) {
      return _getOptionLabel(option, options);
    },
    value: typeof internalValue === 'undefined' ? null : internalValue,
    onChange: function onChange(_event, option) {
      return _onChange(createValue(option, isMulti));
    },
    loading: isFetching
  })));
};
var Select = function Select(props) {
  var _useFieldApi = (0, _useFieldApi2["default"])(props),
    input = _useFieldApi.input,
    isRequired = _useFieldApi.isRequired,
    isDisabled = _useFieldApi.isDisabled,
    isReadOnly = _useFieldApi.isReadOnly,
    disabled = _useFieldApi.disabled,
    multiple = _useFieldApi.multiple,
    isMulti = _useFieldApi.isMulti,
    isClearable = _useFieldApi.isClearable,
    disableClearable = _useFieldApi.disableClearable,
    loadingMessage = _useFieldApi.loadingMessage,
    loadingText = _useFieldApi.loadingText,
    noOptionsMessage = _useFieldApi.noOptionsMessage,
    noOptionsText = _useFieldApi.noOptionsText,
    closeMenuOnSelect = _useFieldApi.closeMenuOnSelect,
    rest = (0, _objectWithoutProperties2["default"])(_useFieldApi, _excluded3);
  return /*#__PURE__*/_react["default"].createElement(_select["default"], (0, _extends2["default"])({}, input, {
    isMulti: multiple || isMulti,
    required: isRequired,
    disabled: isDisabled || isReadOnly || disabled,
    disableClearable: !isClearable || disableClearable,
    loadingText: loadingMessage || loadingText,
    noOptionsMessage: noOptionsMessage || noOptionsText
  }, rest, {
    SelectComponent: InternalSelect
  }));
};
var _default = exports["default"] = Select;